uniform sampler2D usVideoFrame;
uniform float ufColorParameter;  // 0.5 is in the middle
uniform float ufBlendAlpha;


vec2  blockCenterCoord()
{
    vec2 coords;
    coords.x = textureCoordinate.x;
    coords.y = textureCoordinate.y;
    
    float gridSize = 1.0 + 53.0 * ufColorParameter;
    
    coords.x = (coords.x - 0.5) * 480.0 * uv4AspectRatio.z;
    coords.x = coords.x - mod(coords.x, gridSize) + 0.5 * gridSize;
    coords.x = coords.x * (1.0 / (480.0 * uv4AspectRatio.z)) + 0.5;
    
    coords.y = (coords.y - 0.5) * 480.0 * uv4AspectRatio.w;
    coords.y = coords.y - mod(coords.y, gridSize) + 0.5 * gridSize;
    coords.y = coords.y * (1.0 / (480.0 * uv4AspectRatio.w)) + 0.5;
    
    return coords;
}


void main()
{
    vec3 texCoords = texCoord();    // .z component is programmatic alpha
    vec4 vidColor = texture2D(usVideoFrame, texCoords.xy).bgra;
    vidColor = v4ReplaceColor(vidColor);
    vec3 centerColor = texture2D(usVideoFrame, blockCenterCoord()).bgr;
    float alpha = ufBlendAlpha * texCoords.z * vidColor.a * fAlphaMask();
    vec3 newColor = vec3(0.5 * vidColor.rgb + 0.5 * centerColor);
    writeFrag(v4ChangeColor(vec4(newColor, alpha)));
}

